@@ -5,6 +5,8 @@ import hashlib
 import json
 import traceback
 
+from cachetools import TTLCache
+
 from wintersweet.asyncs.pool.redis import redis_pool_manager
 from wintersweet.utils.base import Utils
 
@@ -111,3 +113,29 @@ class ShareCache:
                 Utils.log.error(traceback.format_exc())
 
         return result
+
+
+class CacheWrap:
+    """函数缓存器"""
+    def __init__(self, maxsize=0xffff, ttl=3600):
+        self._cache = TTLCache(maxsize=maxsize, ttl=ttl)
+
+    def _sig(self, func, *args, **kwargs):
+        hash_str = f'{func.__name__}%@@%{args}%@@%{kwargs}'
+        return hashlib.md5(hash_str.encode()).hexdigest()
+
+    def __call__(self, func):
+
+        @functools.wraps(func)
+        async def _wrapper(*args, **kwargs):
+
+            func_sign = self._sig(func, *args, **kwargs)
+            result = self._cache.get(func_sign, None)
+
+            if result is None:
+                result = await func(*args, **kwargs)
+                self._cache[func_sign] = result
+
+            return result
+
+        return _wrapper
